aboutsummaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
authorRafael Espindola <rafael.espindola@gmail.com>2010-11-24 19:23:50 +0000
committerRafael Espindola <rafael.espindola@gmail.com>2010-11-24 19:23:50 +0000
commit1683fcc82397681a64a35884edc9c62c49f2f179 (patch)
tree5a417fbfc4d2b64239bc105debb5c3b215203b2e /test
parent861ef4b1cffcf30ecd5b6a2216b88345f892f0b7 (diff)
downloadexternal_llvm-1683fcc82397681a64a35884edc9c62c49f2f179.zip
external_llvm-1683fcc82397681a64a35884edc9c62c49f2f179.tar.gz
external_llvm-1683fcc82397681a64a35884edc9c62c49f2f179.tar.bz2
Relocate with the symbol if the relocation is of kind NTPOFF.
Patch by David Meyer, I added the test. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@120104 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'test')
-rw-r--r--test/MC/ELF/relocation-386.s47
1 files changed, 34 insertions, 13 deletions
diff --git a/test/MC/ELF/relocation-386.s b/test/MC/ELF/relocation-386.s
index 48cdc35..c14751a 100644
--- a/test/MC/ELF/relocation-386.s
+++ b/test/MC/ELF/relocation-386.s
@@ -1,7 +1,7 @@
// RUN: llvm-mc -filetype=obj -triple i386-pc-linux-gnu %s -o - | elf-dump | FileCheck %s
-// Test that we produce the correct relocation types and that the relocation
-// to .Lfoo uses the symbol and not the section.
+// Test that we produce the correct relocation types and that the relocations
+// correctly point to the section or the symbol.
// Section 3 is bss
// CHECK: # Section 0x00000003
@@ -10,8 +10,18 @@
// CHECK: # Symbol 0x00000001
// CHECK-NEXT: (('st_name', 0x00000005) # '.Lfoo'
-// Symbol 6 is section 3
-// CHECK: # Symbol 0x00000006
+// Symbol 4 is zed
+// CHECK: # Symbol 0x00000004
+// CHECK-NEXT: (('st_name', 0x00000035) # 'zed'
+// CHECK-NEXT: ('st_value', 0x00000000)
+// CHECK-NEXT: ('st_size', 0x00000000)
+// CHECK-NEXT: ('st_bind', 0x00000000)
+// CHECK-NEXT: ('st_type', 0x00000006)
+// CHECK-NEXT: ('st_other', 0x00000000)
+// CHECK-NEXT: ('st_shndx', 0x00000004)
+
+// Symbol 7 is section 3
+// CHECK: # Symbol 0x00000007
// CHECK-NEXT: (('st_name', 0x00000000) # ''
// CHECK-NEXT: ('st_value', 0x00000000)
// CHECK-NEXT: ('st_size', 0x00000000)
@@ -36,10 +46,10 @@
// CHECK-NEXT: ('r_type', 0x0000000a)
// CHECK-NEXT: ),
-// Relocation 3 (bar3@GOTOFF) is done with symbol 6 (bss)
+// Relocation 3 (bar3@GOTOFF) is done with symbol 7 (bss)
// CHECK-NEXT: # Relocation 0x00000003
// CHECK-NEXT: (('r_offset',
-// CHECK-NEXT: ('r_sym', 0x00000006
+// CHECK-NEXT: ('r_sym', 0x00000007
// CHECK-NEXT: ('r_type',
// CHECK-NEXT: ),
@@ -53,49 +63,49 @@
// Relocation 5 (foo@TLSGD) is of type R_386_TLS_GD
// CHECK-NEXT: # Relocation 0x00000005
// CHECK-NEXT: (('r_offset', 0x00000020)
-// CHECK-NEXT: ('r_sym', 0x0000000b)
+// CHECK-NEXT: ('r_sym', 0x0000000d)
// CHECK-NEXT: ('r_type', 0x00000012)
// CHECK-NEXT: ),
// Relocation 6 ($foo@TPOFF) is of type R_386_TLS_LE_32
// CHECK-NEXT: # Relocation 0x00000006
// CHECK-NEXT: (('r_offset', 0x00000025)
-// CHECK-NEXT: ('r_sym', 0x0000000b)
+// CHECK-NEXT: ('r_sym', 0x0000000d)
// CHECK-NEXT: ('r_type', 0x00000022)
// CHECK-NEXT: ),
// Relocation 7 (foo@INDNTPOFF) is of type R_386_TLS_IE
// CHECK-NEXT: # Relocation 0x00000007
// CHECK-NEXT: (('r_offset', 0x0000002b)
-// CHECK-NEXT: ('r_sym', 0x0000000b)
+// CHECK-NEXT: ('r_sym', 0x0000000d)
// CHECK-NEXT: ('r_type', 0x0000000f)
// CHECK-NEXT: ),
// Relocation 8 (foo@NTPOFF) is of type R_386_TLS_LE
// CHECK-NEXT: # Relocation 0x00000008
// CHECK-NEXT: (('r_offset', 0x00000031)
-// CHECK-NEXT: ('r_sym', 0x0000000b)
+// CHECK-NEXT: ('r_sym', 0x0000000d)
// CHECK-NEXT: ('r_type', 0x00000011)
// CHECK-NEXT: ),
// Relocation 9 (foo@GOTNTPOFF) is of type R_386_TLS_GOTIE
// CHECK-NEXT: # Relocation 0x00000009
// CHECK-NEXT: (('r_offset', 0x00000037)
-// CHECK-NEXT: ('r_sym', 0x0000000b)
+// CHECK-NEXT: ('r_sym', 0x0000000d)
// CHECK-NEXT: ('r_type', 0x00000010)
// CHECK-NEXT: ),
// Relocation 10 (foo@TLSLDM) is of type R_386_TLS_LDM
// CHECK-NEXT: # Relocation 0x0000000a
// CHECK-NEXT: (('r_offset', 0x0000003d)
-// CHECK-NEXT: ('r_sym', 0x0000000b)
+// CHECK-NEXT: ('r_sym', 0x0000000d)
// CHECK-NEXT: ('r_type', 0x00000013)
// CHECK-NEXT: ),
// Relocation 11 (foo@DTPOFF) is of type R_386_TLS_LDO_32
// CHECK-NEXT: # Relocation 0x0000000b
// CHECK-NEXT: (('r_offset', 0x00000043)
-// CHECK-NEXT: ('r_sym', 0x0000000b)
+// CHECK-NEXT: ('r_sym', 0x0000000d)
// CHECK-NEXT: ('r_type', 0x00000020)
// CHECK-NEXT: ),
// Relocation 12 (calll 4096) is of type R_386_PC32
@@ -104,6 +114,12 @@
// CHECK-NEXT: ('r_sym', 0x00000000)
// CHECK-NEXT: ('r_type', 0x00000002)
// CHECK-NEXT: ),
+// Relocation 13 (zed@NTPOFF) is of type R_386_TLS_LE and uses the symbol
+// CHECK-NEXT: # Relocation 0x0000000d
+// CHECK-NEXT: (('r_offset', 0x0000004e)
+// CHECK-NEXT: ('r_sym', 0x00000004)
+// CHECK-NEXT: ('r_type', 0x00000011)
+// CHECK-NEXT: ),
.text
bar:
@@ -129,6 +145,11 @@ bar2:
leal foo@TLSLDM(%ebx), %eax
leal foo@DTPOFF(%eax), %edx
calll 4096
+ movl zed@NTPOFF(%eax), %eax
+
+ .section zedsec,"awT",@progbits
+zed:
+ .long 0
.section .rodata.str1.16,"aMS",@progbits,1
.Lfoo: